#!/bin/zsh
if [ $# -ne 4 ]; then
  echo expecting 4 input arguments: "[atm/phy] [year] [mon]" >&2
  exit
fi

knd=$1
year=$2
mon=$3
#exp=$(basename $PWD)
exp=$4

cmon=$(printf "%02d" $mon)
bs=${knd}_3d_${year}${cmon}
if [ -f ${bs}.nc ]; then
  echo already exists
  exit
fi

for fn in ${exp}_${knd}_3d_ml_????????T000000Z.nc; do
  dates=($(cdo -s showdate $fn))
  if [ $? -ne 0 ]; then
    continue
  fi
  datethis=(${(M)dates:#${year}-${cmon}-*})
  dateothers=(${dates:#${year}-${cmon}-*})
  if [ -n "$datethis" ]; then
    if [ -f ${bs}_part1.nc ]; then
      parts=($(ls ${bs}_part*.nc | sed -e 's/\.nc$//g' | sort))
      lastpart=$(sed -e 's/.*part//g' <<< ${parts[-1]})
      thispart=$((lastpart + 1))
    else
      thispart=1
    fi
    pt=${bs}_part${thispart}.nc
    if [ -z "$dateothers" ]; then
      echo link  file "\e[4m$fn\e[0m" as "\e[4m$pt\e[0m"
      ln -s $fn $pt
    else
      echo select file "\e[4m$fn\e[0m" to "\e[4m$pt\e[0m"
      cdo -s selmon,$mon -selyear,$year $fn $pt
    fi
  fi
done

parts=($(ls ${bs}_part*.nc | sed -e 's/\.nc$//g' | sort))
lastpart=$(sed -e 's/.*part//g' <<< ${parts[-1]})
if [ $lastpart -eq 1 ]; then
  echo rename sole part
  mv ${bs}_part${lastpart}.nc ${bs}.nc
else
  echo merge parts
  cdo -s mergetime ${^parts}.nc ${bs}.nc
  rm ${^parts}.nc
fi
