;
;
; ATTENTION: script has been run on mistral                                    
;
;script to create zonal wind plots for the months of January and July for UA-ICON, ICON, and URAP


;load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl" 
;load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl" 
;load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl" 

begin

var="ta"

;the inputfiles need to be zonal means of the time means of the desired years

;define the names for the inputfiles

; UA-ICON, January
infile          ="../UA-ICON/data/Fig7a_ta_Fig8a_ua_zm_mm1980-1999tm_01.nc"
ua_01           =addfile(infile,"r")        
var_ua_01       =ua_01->ua(0,:,:,0)
zg_ua_01        =ua_01->zg(:,0,0)*0.001
var_ua_01!0   = "height"      ; name the dimension
var_ua_01&height = zg_ua_01   ; assign the coordinate variable

printVarSummary(var_ua_01)

; UA-ICON, July             
infile          ="../UA-ICON/data/Fig7d_ta_Fig8d_ua_zm_mm1980-1999tm_07.nc"
ua_07           =addfile(infile,"r")                         
var_ua_07       =ua_07->ua(0,:,:,0)
zg_ua_07        =ua_07->zg(:,0,0)*0.001
var_ua_07!0   = "height"      ; name the dimension
var_ua_07&height = zg_ua_07   ; assign the coordinate variable

; LA-ICON, January
infile          ="../ICON/data/Fig7b_ta_Fig8b_ua_zm_mm1980-1999tm_01.nc"          
la_01           =addfile(infile,"r")                         
var_la_01       =la_01->ua(0,:,:,0)
zg_la_01        =la_01->zg(:,0,0)*0.001
var_la_01!0   = "height"      ; name the dimension
var_la_01&height = zg_la_01   ; assign the coordinate variable

; LA-ICON, July   
infile          ="../ICON/data/Fig7e_ta_Fig8e_ua_zm_mm1980-1999tm_07.nc"          
la_07           =addfile(infile,"r")
var_la_07       =la_07->ua(0,:,:,0)
zg_la_07        =la_07->zg(:,0,0)*0.001
var_la_07!0   = "height"      ; name the dimension
var_la_07&height = zg_la_07   ; assign the coordinate variable

;URAP, January
infile          ="../URAP/data/Fig8c_ua_urap_01.nc"     
sa_01           =addfile(infile,"r")
var_sa_01       =sa_01->u(0,:,:,0)
p_sa_01         =sa_01->lev(:)
z_sa_01         =7 * log(1000./ p_sa_01) ; convert to log pressure
var_sa_01&lev   =z_sa_01   ; assign the coordinate variable

printVarSummary(var_sa_01)

;URAP, July       
infile          ="../URAP/data/Fig8f_ua_urap_07.nc"      
sa_07           =addfile(infile,"r")
var_sa_07       =sa_07->u(0,:,:,0)
p_sa_07         =sa_07->lev(:)
z_sa_07         =7 * log(1000./ p_sa_07) ; convert to log pressure
var_sa_07&lev   =z_sa_07   ; assign the coordinate variable


;************************************************
; create plot
;************************************************

wks = gsn_open_wks("pdf","./u_3x2")              ; send graphics to PNG file
plot_a = new(6,graphic)                          ; create a plot array


;define joint plot characteristics

res              = True                         ; plot mods desired
res@gsnDraw      = False                        ; don't draw yet
res@gsnFrame     = False                        ; don't advance frame yet
res@cnLevelSelectionMode = "ManualLevels"       ; manually select levels
res@cnLevelSpacingF      = 10.                  ; contour spacing
res@cnMinLevelValF       = -90.                 ; min level
res@cnMaxLevelValF       = 90.                  ; max level
res@cnLineLabelsOn       = True                 ; turn on line labels
res@cnFillOn             = True                 ; turn on color fill
res@cnFillPalette        = "BlueDarkRed18"
res@trYMinF           = 0.
res@trYMaxF           = 150.
res@gsnYAxisIrregular2Linear = True 
res@gsnLeftString   = ""
res@gsnRightString   = ""
res@tiYAxisOffsetXF = 0.010
res@tiXAxisOffsetYF = 0.005
res@tiXAxisString   = "Latitude"
res@tiYAxisString   = "Height (km)"
res@lbLabelBarOn        = False              ; turn off individual cb's
res@cnInfoLabelOn       = False              ; turn off cn info label
res@tiMainOffsetYF      = -0.005             ; displace main titles vertically

;;;;;
;plot
;;;;;

; UA-ICON, January
res@tiMainString    = "UA-ICON, January"
plot_a(0)   = gsn_csm_contour(wks,var_ua_01,res)

; UA-ICON, July
res@tiMainString    = "UA-ICON, July"        
plot_a(3)   = gsn_csm_contour(wks,var_ua_07,res)

; LA-ICON, January
res@tiMainString    = "ICON, January"
plot_a(1)   = gsn_csm_contour(wks,var_la_01,res)

; LA-ICON, July
res@tiMainString    = "ICON, July"       
plot_a(4)   = gsn_csm_contour(wks,var_la_07,res)

;URAP, January
res@tiMainString    = "URAP, January"
plot_a(2)   = gsn_csm_contour(wks,var_sa_01,res)

;URAP, July         
res@tiMainString    = "URAP, July"
plot_a(5)   = gsn_csm_contour(wks,var_sa_07,res)


;*******************************************
;  create panel resources
;*******************************************
 pres                  = True                ; mods desired
 pres@gsnFrame         = False               ; save panel until both ready
 pres@gsnPanelLabelBar = True                ; commom label bar
 pres@lbTitleString    = "u(m/s)"            ; title string
 pres@lbTitlePosition  = "Right"
 pres@lbTitleDirection = "Across"            ; title direction
 pres@lbTitleFontHeightF= .012               ; make title smaller
 pres@lbLabelStride    = 1                   ; every other label
 pres@lbLabelFontHeightF = 0.01
 pres@vpWidthF           = 0.5 ;* vpw        ; labelbar width
 pres@vpHeightF          = 0.05 ;* vph       ; labelbar height


 gsn_panel(wks,plot_a,(/2,3/),pres)          ; create panel

frame(wks)

end
