;***********************************************

load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"  

;************************************************
begin

; Plot numerical (color) and analyitcal (contour) solution 
; for the pressure perturbation simulated on the grid R2B6L180 
; at a height-longitude cross section 
; at the equator between lon = 155E and lon = 205E 
; and at time 60 s.

datafilename = "Fig4ac_Fig5a_sound_wave_test_case_R2B6L180_rotation_off.nc"  ;without rotation
;datafilename = "Fig4bd_Fig5b_sound_wave_test_case_R2B6L180_rotation_on.nc"   ;with rotation
datafilename2 = "Fig4a_Fig5a_sound_wave_test_case_R2B7L360_rotation_off.nc"  ;without rotation
;datafilename2 = "Fig4b_Fig5b_sound_wave_test_case_R2B7L360_rotation_on.nc"   ;with rotation

wks = gsn_open_wks("png","figure_rotation_off_pres")
;wks = gsn_open_wks("png","figure_rotation_on_pres")

datafile = addfile(datafilename, "r")
datafile2 = addfile(datafilename2, "r")

lon   = datafile->lon(:)     ; Dims: (lon)
nlon  = dimsizes(lon)

lat   = datafile->lat(:)     ; Dims: (lat)
nlat  = dimsizes(lat)

lev   = datafile->height_3(:)  ; Dims: (height_3)  
nlev  = dimsizes(lev)    

lev2  = datafile->height(:)    ; Dims: (height)
nlev2 = dimsizes(lev2)

hgt   = datafile->z_ifc(:,:,:) ; Dims: (height_3,lat,lon)
hgt   = 0.001 * hgt  ; in km

hgt2  = datafile->z_mc(:,:,:)  ; Dims: (height,lat,lon)
hgt2  = 0.001 * hgt2 ; in km

lon2   = datafile2->lon(:)     ; Dims: (lon)
nlon2  = dimsizes(lon2)

lat2   = datafile2->lat(:)     ; Dims: (lat)
nlat2  = dimsizes(lat2)

lev2   = datafile2->height_3(:)  ; Dims: (height_3)  
nlev2  = dimsizes(lev2)    

lev22  = datafile2->height(:)    ; Dims: (height)
nlev22 = dimsizes(lev22)

hgt2   = datafile2->z_ifc(:,:,:) ; Dims: (height_3,lat,lon)
hgt2   = 0.001 * hgt2  ; in km

hgt22  = datafile2->z_mc(:,:,:)  ; Dims: (height,lat,lon)
hgt22  = 0.001 * hgt22 ; in km

; var  -> numerical pressure difference
; var2 -> analytical pressure difference
; time = 0 -> here, this means 60 s after initialization
var   = datafile->extra_3d1(0,:,:,:) ; Dims: (time,height,lat,lon)
var2  = datafile2->extra_3d2(0,:,:,:) ; Dims: (time,height,lat,lon)

var  = var  * 1.
var2 = var2 * 1.
  
iplat = 0

x2d = conform_dims((/nlev2,nlon/), lon, 1)
y2d = hgt2(:,iplat,:)

x2d2 = conform_dims((/nlev22,nlon2/), lon2, 1)
y2d2 = hgt22(:,iplat,:)
 
gsn_define_colormap(wks,"MPL_bwr") 

ResC                      = True
ResC@gsnMaximize          = True             ; maxmize plot in frame
ResC@cnFillOn             = True             ; do color fill
ResC@cnFillMode           = "areafill" 
ResC@cnLinesOn            = False            ; contour lines off
ResC@cnLevelSelectionMode = "ManualLevels"   ; manual level selection
ResC@cnMinLevelValF       = -50              ; min value
ResC@cnMaxLevelValF       = 50               ; max value
ResC@cnLevelSpacingF      = 10.              ; spacing
ResC@gsnSpreadColors      = True             ; use full color map
ResC@pmTickMarkDisplayMode  = "conditional"
ResC@gsnAddCyclic           = False
ResC@lbOrientation          = "vertical"
ResC@lbTitleOn            = False 
ResC@lbTitlePosition      = "Right"          ; title location
ResC@lbTitleDirection     = "Across"         ; letter angle
ResC@lbTitleAngleF        = 90.              ; title angle
ResC@lbTitleFontHeightF   = 0.02             ; font height
ResC@trGridType           = "TriangularMesh" ; used for irregular mesh triangulation
ResC@sfXArray             = x2d
ResC@sfYArray             = y2d
ResC@trYMinF              = 0.0             ;-- y-axis minimum value
ResC@trYMaxF              = 100.0           ;-- y-axis maximum value
ResC@trXMinF              = 155             ;-- x-axis minimum value
ResC@trXMaxF              = 205             ;-- x-axis maximum value
ResC@tmYLMode             = "Manual"        ;-- set tickmarks resources manually
ResC@tmYLTickSpacingF     = 10.0            ;-- label every 10th tickmark
ResC@tmYLMinorPerMajor    = 1               ;-- draw  1 minor tickmarks between
                                            ;-- the labeled major tickmarks
ResC@tmYLAutoPrecision    = False
ResC@tmYLPrecision        = 2               ;-- choose decimals of labels
ResC@tmXBMode             = "Manual"        ;-- set tickmarks resources manually
ResC@tmXBTickSpacingF     = 10.             ;-- label every 2nd tickmark
ResC@tmXBMinorPerMajor    = 1               ;-- draw 1 minor tickmarks between 
                                            ;-- the labeled major tickmarks
ResC@tiXAxisString        = "longitude (deg)"
ResC@tiYAxisString        = "altitude (km)"
ResC@tiMainString         = ""
ResC@tiMainFontHeightF    = 0.025
ResC@gsnLeftString        = ""
ResC@gsnCenterString      = ""
ResC@gsnCenterStringFontHeightF   = 0.02
ResC@gsnRightString       = "Pa"
ResC@gsnLeftString        = "Pressure perturbation"
ResC@gsnDraw              = False
ResC@gsnFrame             = False

;--------------------------------------------------------------------------------

ResD                      = ResC
delete(ResD@sfXArray)
delete(ResD@sfYArray)
ResD@sfXArray             = x2d2
ResD@sfYArray             = y2d2
ResD@cnFillOn             = False             ; no color fill
ResD@cnLinesOn            = True              ; contour lines on
ResD@cnLevelSelectionMode = "ManualLevels"    ; manual level selection
ResD@cnMinLevelValF       = -50               ; min value
ResD@cnMaxLevelValF       = 50                ; max value
ResD@cnLevelSpacingF      = 10.               ; spacing
ResD@cnLineLabelDensityF  = 0.8               ; density of labels on contour line (default: 1.0)
ResD@cnMonoLineThickness  = True              ; all contour lines with same thickness
ResD@cnLineThicknessF     = 1.5              ; contour line thickness (default: 1.0)
ResD@cnLineLabelBackgroundColor = -1          ; transparent background box for labels
ResD@cnLineLabelPlacementMode = "constant"    ; no contour line behind label
ResD@cnInfoLabelOn         = False             ; turn off info label
ResD@gsnContourZeroLineThicknessF = 0.0  	    ; thickness of zero contour
ResD@gsnContourNegLineDashPattern = 1              ; sets negative contours to dash pattern 1

pl = gsn_csm_contour(wks,var(:,iplat,:),ResC)

delete(ResC)

pl2 = gsn_csm_contour(wks,var2(:,iplat,:),ResD)

delete(ResD)

overlay(pl,pl2)

draw(pl)
frame(wks)

delete(wks)

end
