;***********************************************

load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"  

;************************************************
begin

; Plot difference between numerical and analytical solution 
; for the pressure perturbation simulated on the grid R2B6L180 
; at a height-longitude cross section 
; at the equator between lon = 155E and lon = 205E
; and at time 60 s.

datafilename = "Fig4ac_Fig5a_sound_wave_test_case_R2B6L180_rotation_off.nc"  ;without rotation
;datafilename = "Fig4bd_Fig5b_sound_wave_test_case_R2B6L180_rotation_on.nc"   ;with rotation

wks = gsn_open_wks("png","figure_rotation_off_presdiff")
;wks = gsn_open_wks("png","figure_rotation_on_presdiff")

datafile = addfile(datafilename, "r")

lon   = datafile->lon(:)     ; Dims: (lon)
nlon  = dimsizes(lon)

lat   = datafile->lat(:)     ; Dims: (lat)
nlat  = dimsizes(lat)

lev   = datafile->height_3(:)  ; Dims: (height_3)  
nlev  = dimsizes(lev)    

lev2  = datafile->height(:)    ; Dims: (height)
nlev2 = dimsizes(lev2)

hgt   = datafile->z_ifc(:,:,:) ; Dims: (height_3,lat,lon)
hgt   = 0.001 * hgt  ; in km

hgt2  = datafile->z_mc(:,:,:)  ; Dims: (height,lat,lon)
hgt2  = 0.001 * hgt2 ; in km

; var  -> numerical pressure difference
; var2 -> analytical pressure difference
; time = 0 -> here, this means 60 s after initialization
var   = datafile->extra_3d1(0,:,:,:) ; Dims: (time,height,lat,lon)
var2  = datafile->extra_3d2(0,:,:,:) ; Dims: (time,height,lat,lon)
  
iplat = 0

x2d2 = conform_dims((/nlev2,nlon/), lon, 1)
y2d2 = hgt2(:,iplat,:)

gsn_define_colormap(wks,"MPL_bwr") 

ResC                      = True
ResC@gsnMaximize          = True             ; maxmize plot in frame
ResC@cnFillOn             = True             ; do color fill
ResC@cnFillMode           = "areafill" 
ResC@cnLinesOn            = False            ; contour lines off
ResC@cnLevelSelectionMode = "ManualLevels"   ; manual level selection
ResC@cnMinLevelValF       = -2               ; min value
ResC@cnMaxLevelValF       = 2                ; max value
ResC@cnLevelSpacingF      = 0.25             ; spacing
ResC@gsnSpreadColors      = True             ; use full color map
ResC@pmTickMarkDisplayMode  = "conditional"
ResC@gsnAddCyclic           = False
ResC@lbOrientation          = "vertical"
ResC@lbTitleOn            = False 
ResC@lbLabelStride        = 2
ResC@trGridType           = "TriangularMesh" ; used for irregular mesh triangulation
ResC@sfXArray             = x2d2
ResC@sfYArray             = y2d2
ResC@trYMinF              = 0.0             ;-- y-axis minimum value
ResC@trYMaxF              = 100.0           ;-- y-axis maximum value
ResC@trXMinF              = 155             ;-- x-axis minimum value
ResC@trXMaxF              = 205             ;-- x-axis maximum value
ResC@tmYLMode             = "Manual"        ;-- set tickmarks resources manually
ResC@tmYLTickSpacingF     = 10.0            ;-- label every 10th tickmark
ResC@tmYLMinorPerMajor    = 1               ;-- draw  1 minor tickmarks between
                                            ;-- the labeled major tickmarks
ResC@tmYLAutoPrecision    = False
ResC@tmYLPrecision        = 2               ;-- choose decimals of labels
ResC@tmXBMode             = "Manual"        ;-- set tickmarks resources manually
ResC@tmXBTickSpacingF     = 10.             ;-- label every 2nd tickmark
ResC@tmXBMinorPerMajor    = 1               ;-- draw 1 minor tickmarks between 
                                            ;-- the labeled major tickmarks
ResC@tiXAxisString        = "longitude (deg)"
ResC@tiYAxisString        = "altitude (km)"
ResC@tiMainString        = ""
ResC@tiMainFontHeightF   = 0.025
ResC@gsnLeftString       = ""
ResC@gsnCenterString     = ""
ResC@gsnCenterStringFontHeightF   = 0.02
ResC@gsnRightString      = "Pa"
ResC@gsnLeftString      = "Pressure difference"
ResC@gsnDraw              = False
ResC@gsnFrame             = False

pl = gsn_csm_contour(wks,var2(:,iplat,:)-var(:,iplat,:),ResC)

delete(ResC)

draw(pl)
frame(wks)

delete(wks)

end
