;***********************************************

load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"  

;************************************************
begin

; Plot L2 and Lmax norm of the pressure pressure field 
; at a height-longitude cross section at the equator and at time 60 s. 
; Values for L2 and Lmax are computed with 'plot_sound_wave_test_case_4_convergence.ncl'

; 1) Without rotation
;--------------------

x1 = (/1594.1, 1195.6, 797.0, 597.8, 398.5, 298.9, 199.3, 149.5, 99.6/)

y1 = new((/4,9/),float)
;L2
y1(3,1) = 0.60535    ;grid R2B5L90
y1(3,2) = 0.314672   ;grid R3B5L136
y1(3,3) = 0.18694    ;grid R2B6L180
y1(3,4) = 0.074482   ;grid R3B6L277
y1(3,5) = 0.0452672  ;grid R2B7L360
;Lmax
y1(2,1) = 6.20024    ;grid R2B5L90
y1(2,2) = 3.63604    ;grid R3B5L136
y1(2,3) = 2.01728    ;grid R2B6L180
y1(2,4) = 1.13455    ;grid R3B6L277
y1(2,5) = 0.795967   ;grid R2B7L360
;(dx)
b1 = 0.02*66.0/1000.
y1(1,:) = b1 * x1(:)
;(dx)^2
b2 = 0.00025*66.0*66.0/1000./1000.
y1(0,:) = b2 * x1(:) * x1(:)

wks = gsn_open_wks("eps","figure_rotation_off_convergence")

res1                         = True
res1@tiXAxisString           = "mean horizontal grid mesh size ~F33~D~F21~x (m)"
res1@tiYAxisString           = "error (Pa)"
res1@xyYStyle                = "Log"
res1@xyXStyle                = "Log"
res1@xyMarkLineModes         = (/"Lines","Lines","MarkLines","MarkLines"/)
res1@xyMarkerSizeF           = 0.02
res1@xyMarkerThicknessF      = 2.2
res1@xyLineThicknesses       = (/3.5, 3.5, 3.5, 3.5/)    ; make second line thicker
res1@trXMinF                 = 99.6             ;-- x-axis minimum value
res1@trXMaxF                 = 1594.1             ;-- x-axis maximum value
res1@pmLegendDisplayMode     = "Always"              ; turn on legend
res1@pmLegendSide            = "Top"                 ; Change location of 
res1@pmLegendParallelPosF    = 0.85                   ; move units right
res1@pmLegendOrthogonalPosF  = -1.0                  ; more neg = down
res1@pmLegendWidthF          = 0.12                  ; Change width and
res1@pmLegendHeightF         = 0.25                  ; height of legend.
res1@lgLabelFontHeightF      = .02                   ; change font height
res1@lgPerimOn               = False                 ; no box around
res1@xyExplicitLegendLabels  = (/"~F34~5~F33~D~F21~x~S~2","~F34~5~F33~D~F21~x","L~S~~F34~%~N~~F21~-norm","L~S~2~N~-norm"/)

plot = gsn_csm_xy(wks, x1, y1, res1)

delete(res1)
delete(wks)

; 2) With rotation
;--------------------

x1 = (/1594.1, 1195.6, 797.0, 597.8, 398.5, 298.9, 199.3, 149.5, 99.6/)

y1 = new((/4,9/),float)
;L2
y1(3,1) = 0.84394    ;grid R2B5L90
y1(3,2) = 0.41137    ;grid R3B5L136
y1(3,3) = 0.258598   ;grid R2B6L180
y1(3,4) = 0.138894   ;grid R3B6L277
y1(3,5) = 0.101004   ;grid R2B7L360
;Lmax
y1(2,1) = 10.9433    ;grid R2B5L90
y1(2,2) = 5.2024     ;grid R3B5L136
y1(2,3) = 3.01289    ;grid R2B6L180
y1(2,4) = 1.85656    ;grid R3B6L277
y1(2,5) = 1.37334    ;grid R2B7L360
;(dx)
b1 = 0.035*66.0/1000.
y1(1,:) = b1 * x1(:)
;(dx)^2
b2 = 0.000437*66.0*66.0/1000./1000.
y1(0,:) = b2 * x1(:) * x1(:)

wks = gsn_open_wks("eps","figure_rotation_on_convergence")

res1                         = True
res1@tiXAxisString           = "mean horizontal grid mesh size ~F33~D~F21~x (m)"
res1@tiYAxisString           = "error (Pa)"
res1@xyYStyle                = "Log"
res1@xyXStyle                = "Log"
res1@xyMarkLineModes         = (/"Lines","Lines","MarkLines","MarkLines"/)
res1@xyMarkerSizeF           = 0.02
res1@xyMarkerThicknessF      = 2.2
res1@xyLineThicknesses       = (/3.5, 3.5, 3.5, 3.5/)    ; make second line thicker
res1@trXMinF                 = 99.6             ;-- x-axis minimum value
res1@trXMaxF                 = 1594.1             ;-- x-axis maximum value
res1@pmLegendDisplayMode     = "Always"              ; turn on legend
res1@pmLegendSide            = "Top"                 ; Change location of 
res1@pmLegendParallelPosF    = 0.85                   ; move units right
res1@pmLegendOrthogonalPosF  = -1.0                  ; more neg = down
res1@pmLegendWidthF          = 0.12                  ; Change width and
res1@pmLegendHeightF         = 0.25                  ; height of legend.
res1@lgLabelFontHeightF      = .02                   ; change font height
res1@lgPerimOn               = False                 ; no box around
res1@xyExplicitLegendLabels  = (/"~F34~5~F33~D~F21~x~S~2","~F34~5~F33~D~F21~x","L~S~~F34~%~N~~F21~-norm","L~S~2~N~-norm"/)

plot = gsn_csm_xy(wks, x1, y1, res1)

delete(res1)
delete(wks)

end
